Module: Kitchen::Verifier
- Defined in:
- lib/kitchen/verifier/pester_version.rb,
lib/kitchen/verifier/pester.rb
Overview
Namespace for Test Kitchen verifier plugins.
Defined Under Namespace
Classes: Pester
Constant Summary collapse
- PESTER_VERSION =
Version of the kitchen-pester gem.
Kept in its own file so that the gemspec can read it without loading test-kitchen, which is not yet available when the gemspec is evaluated.
"1.2.1"